==> thx_l10n-0.1.1.tar.gz: thx_l10n-0.1.1/thx/l10n/api/version1/views.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import exceptions, viewsets
from rest_framework.decorators import action
from rest_framework.response import Response
from thx.api.mixins import ThuxModelMixin

from ... import models
from . import serializers

STATUS_CODES = ((0, _('disable')), (1, _('enable')),)


# COUNTRY
class CountryViewSet(ThuxModelMixin, viewsets.ModelViewSet):
    """
    CountryViewSet
    -----------

    :action list: Return the country list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given country.
        `Profiles`: `superuser`, `staff`

    :action light: Return the country list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new country instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a country instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a country instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a country instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.Country.objects.all()
    serializer_class = serializers.CountrySerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_superuser and profile == 'superuser':
            return qs
        if user.is_staff and profile == 'staff':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_superuser and profile == 'superuser':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable', 'light',
                'status_choices'
            ]:
                return
        if user.is_staff and profile == 'staff':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable', 'light',
                'status_choices'
            ]:
                return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Country{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a country instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a country instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)


# ADMINISTRATIVE AREA
class AdministrativeAreaViewSet(ThuxModelMixin, viewsets.ModelViewSet):
    """
    AdministrativeAreaViewSet
    -----------

    :action list: Return the administrative area list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given administrative area.
        `Profiles`: `superuser`, `staff`

    :action light: Return the administrative area list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new administrative area instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a administrative area instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a administrative area instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a administrative area instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.AdministrativeArea.objects.all()
    serializer_class = serializers.AdministrativeAreaSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_superuser and profile == 'superuser':
            return qs
        if user.is_staff and profile == 'staff':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_superuser and profile == 'superuser':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable', 'light',
                'status_choices'
            ]:
                return
        if user.is_staff and profile == 'staff':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable', 'light',
                'status_choices'
            ]:
                return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'AdministrativeArea{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a administrative area instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a administrative area instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)

==> thx_l10n-0.1.2.tar.gz: thx_l10n-0.1.2/thx/l10n/api/version1/views.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import viewsets
from rest_framework.decorators import action
from rest_framework.response import Response
from thx.api.mixins import ThuxModelMixin

from thx.role.core.views import ThuxRoleViewSetMixin

from ... import models
from . import serializers, filters, permissions

STATUS_CODES = ((0, _('disable')), (1, _('enable')),)


# COUNTRY
class CountryViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    """
    CountryViewSet
    -----------

    :action list: Return the country list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given country.
        `Profiles`: `superuser`, `staff`

    :action light: Return the country list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new country instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a country instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a country instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a country instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.Country.objects.all()
    serializer_class = serializers.CountrySerializer
    filter_backends = (filters.CountryFilterBackend,)
    permission_classes = (permissions.CountryPermission,)

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a country instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a country instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)


# ADMINISTRATIVE AREA
class AdministrativeAreaViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    """
    AdministrativeAreaViewSet
    -----------

    :action list: Return the administrative area list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given administrative area.
        `Profiles`: `superuser`, `staff`

    :action light: Return the administrative area list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new administrative area instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a administrative area instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a administrative area instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a administrative area instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.AdministrativeArea.objects.all()
    serializer_class = serializers.AdministrativeAreaSerializer
    filter_backends = (filters.AdministrativeAreaFilterBackend,)
    permission_classes = (permissions.AdministrativeAreaPermission,)

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a administrative area instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a administrative area instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)
